==> owlapi-parsers-3.4.1-sources.jar: org/coode/owlapi/rdfxml/parser/TPVersionIRIHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.rdfxml.parser;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyID;
import org.semanticweb.owlapi.model.UnloadableImportException;
import org.semanticweb.owlapi.vocab.OWLRDFVocabulary;

/**
 * Author: Matthew Horridge<br>
 * The University of Manchester<br>
 * Information Management Group<br>
 * Date: 23-Apr-2009
 */
@SuppressWarnings("javadoc")
public class TPVersionIRIHandler extends TriplePredicateHandler {

    public TPVersionIRIHandler(OWLRDFConsumer consumer) {
        super(consumer, OWLRDFVocabulary.OWL_VERSION_IRI.getIRI());
    }


    @Override
    public void handleTriple(IRI subject,
            IRI predicate,
            IRI object) throws UnloadableImportException {
        OWLOntology ontology = getConsumer().getOntology();
        // only setup the versionIRI if it is null before this point
        if (ontology != null && ontology.getOntologyID().getVersionIRI() == null) {
            IRI ontologyIRI = ontology.getOntologyID().getOntologyIRI();
            IRI versionIRI = object;
            // If there was no ontologyIRI before this point and the subject of
            // this statement was not anonymous,
            // then use the subject IRI as the ontology IRI, else we keep the
            // previous definition for the ontology IRI
            if (ontologyIRI == null && !isAnonymous(subject)) {
                ontologyIRI = subject;
            }
            OWLOntologyID ontologyID = new OWLOntologyID(ontologyIRI, versionIRI);
            getConsumer().setOntologyID(ontologyID);
        }
        consumeTriple(subject, predicate, object);
    }


    @Override
    @SuppressWarnings("unused")
    public boolean canHandleStreaming(IRI subject,
            IRI predicate,
            IRI object) {
        // Always apply at the end
        return false;
    }


    @Override
    @SuppressWarnings("unused")
    public boolean canHandle(IRI subject, IRI predicate, IRI object) {
        return predicate.equals(OWLRDFVocabulary.OWL_VERSION_IRI.getIRI());
    }
}

==> owlapi-parsers-3.4.2-sources.jar: org/coode/owlapi/rdfxml/parser/TPVersionIRIHandler.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.rdfxml.parser;

import org.semanticweb.owlapi.model.IRI;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.model.OWLOntologyID;
import org.semanticweb.owlapi.model.UnloadableImportException;
import org.semanticweb.owlapi.vocab.OWLRDFVocabulary;

/** Author: Matthew Horridge<br>
 * The University of Manchester<br>
 * Information Management Group<br>
 * Date: 23-Apr-2009 */
@SuppressWarnings("javadoc")
public class TPVersionIRIHandler extends TriplePredicateHandler {
    public TPVersionIRIHandler(OWLRDFConsumer consumer) {
        super(consumer, OWLRDFVocabulary.OWL_VERSION_IRI.getIRI());
    }

    @Override
    public void handleTriple(IRI subject, IRI predicate, IRI object)
            throws UnloadableImportException {
        OWLOntology ontology = getConsumer().getOntology();
        // only setup the versionIRI if it is null before this point
        if (ontology != null && ontology.getOntologyID().getVersionIRI() == null) {
            IRI ontologyIRI = ontology.getOntologyID().getOntologyIRI();
            IRI versionIRI = object;
            // If there was no ontologyIRI before this point and the subject of
            // this statement was not anonymous,
            // then use the subject IRI as the ontology IRI, else we keep the
            // previous definition for the ontology IRI
            if (ontologyIRI == null && !isAnonymous(subject)) {
                ontologyIRI = subject;
            }
            OWLOntologyID ontologyID = new OWLOntologyID(ontologyIRI, versionIRI);
            getConsumer().setOntologyID(ontologyID);
        }
        consumeTriple(subject, predicate, object);
    }

    @Override
    public boolean canHandleStreaming(IRI subject, IRI predicate, IRI object) {
        // Always apply at the end
        return false;
    }

    @Override
    public boolean canHandle(IRI subject, IRI predicate, IRI object) {
        return predicate.equals(OWLRDFVocabulary.OWL_VERSION_IRI.getIRI());
    }
}
